==> validation-model-arlington-1.25.82-sources.jar: org/verapdf/gf/model/impl/arlington/GFACIDSystemInfo.java <==
/**
 * This file is part of veraPDF Validation, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.gf.model.impl.arlington;

import org.verapdf.cos.*;
import org.verapdf.model.alayer.*;
import org.verapdf.gf.model.impl.containers.StaticContainers;
import org.verapdf.tools.StaticResources;
import java.util.*;
import org.verapdf.pd.PDNameTreeNode;
import org.verapdf.as.ASAtom;
import java.util.stream.Collectors;
import org.verapdf.pd.structure.PDNumberTreeNode;

public class GFACIDSystemInfo extends GFAObject implements ACIDSystemInfo {

	public GFACIDSystemInfo(COSBase baseObject, COSBase parentObject, String keyName) {
		super(baseObject, parentObject, keyName, "ACIDSystemInfo");
	}

	@Override
	public Boolean getcontainsOrdering() {
		return this.baseObject.knownKey(ASAtom.getASAtom("Ordering"));
	}

	public COSObject getOrderingValue() {
		COSObject object = this.baseObject.getKey(ASAtom.getASAtom("Ordering"));
		return object;
	}

	@Override
	public Boolean getOrderingHasTypeStringAscii() {
		COSObject Ordering = getOrderingValue();
		return getHasTypeStringAscii(Ordering);
	}

	@Override
	public Boolean getcontainsRegistry() {
		return this.baseObject.knownKey(ASAtom.getASAtom("Registry"));
	}

	public COSObject getRegistryValue() {
		COSObject object = this.baseObject.getKey(ASAtom.getASAtom("Registry"));
		return object;
	}

	@Override
	public Boolean getRegistryHasTypeStringAscii() {
		COSObject Registry = getRegistryValue();
		return getHasTypeStringAscii(Registry);
	}

	@Override
	public Boolean getcontainsSupplement() {
		return this.baseObject.knownKey(ASAtom.getASAtom("Supplement"));
	}

	public COSObject getSupplementValue() {
		COSObject object = this.baseObject.getKey(ASAtom.getASAtom("Supplement"));
		return object;
	}

	@Override
	public Boolean getSupplementHasTypeInteger() {
		COSObject Supplement = getSupplementValue();
		return getHasTypeInteger(Supplement);
	}

}

==> validation-model-arlington-1.25.347-sources.jar: org/verapdf/gf/model/impl/arlington/GFACIDSystemInfo.java <==
/**
 * This file is part of veraPDF Validation, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.gf.model.impl.arlington;

import org.verapdf.cos.*;
import org.verapdf.model.alayer.*;
import org.verapdf.gf.model.impl.containers.StaticContainers;
import org.verapdf.tools.StaticResources;
import java.util.*;
import org.verapdf.pd.PDNameTreeNode;
import org.verapdf.as.ASAtom;
import java.util.stream.Collectors;
import org.verapdf.pd.structure.PDNumberTreeNode;

public class GFACIDSystemInfo extends GFAObject implements ACIDSystemInfo {

	public GFACIDSystemInfo(COSBase baseObject, COSBase parentObject, String keyName) {
		super(baseObject, parentObject, keyName, "ACIDSystemInfo");
	}

	@Override
	public Boolean getcontainsOrdering() {
		return this.baseObject.knownKey(ASAtom.getASAtom("Ordering"));
	}

	public COSObject getOrderingValue() {
		COSObject object = this.baseObject.getKey(ASAtom.getASAtom("Ordering"));
		return object;
	}

	@Override
	public String getOrderingType() {
		COSObject Ordering = getOrderingValue();
		return getObjectType(Ordering);
	}

	@Override
	public Boolean getOrderingHasTypeStringAscii() {
		COSObject Ordering = getOrderingValue();
		return getHasTypeStringAscii(Ordering);
	}

	@Override
	public Boolean getcontainsRegistry() {
		return this.baseObject.knownKey(ASAtom.getASAtom("Registry"));
	}

	public COSObject getRegistryValue() {
		COSObject object = this.baseObject.getKey(ASAtom.getASAtom("Registry"));
		return object;
	}

	@Override
	public String getRegistryType() {
		COSObject Registry = getRegistryValue();
		return getObjectType(Registry);
	}

	@Override
	public Boolean getRegistryHasTypeStringAscii() {
		COSObject Registry = getRegistryValue();
		return getHasTypeStringAscii(Registry);
	}

	@Override
	public Boolean getcontainsSupplement() {
		return this.baseObject.knownKey(ASAtom.getASAtom("Supplement"));
	}

	public COSObject getSupplementValue() {
		COSObject object = this.baseObject.getKey(ASAtom.getASAtom("Supplement"));
		return object;
	}

	@Override
	public String getSupplementType() {
		COSObject Supplement = getSupplementValue();
		return getObjectType(Supplement);
	}

	@Override
	public Boolean getSupplementHasTypeInteger() {
		COSObject Supplement = getSupplementValue();
		return getHasTypeInteger(Supplement);
	}

}
